@@ -27,6 +27,20 @@ _max_connections = 10
 # global connection pool
 connection_pool = None
 
+
+class CQLConnectionError(CQLEngineException): pass
+
+
+class RowResult(tuple):
+    pass
+
+QueryResult = namedtuple('RowResult', ('columns', 'results'))
+
+
+def _column_tuple_factory(colnames, values):
+    return tuple(colnames), [RowResult(v) for v in values]
+
+
 def setup(hosts, username=None, password=None, max_connections=10, default_keyspace=None, consistency='ONE'):
     """
     Records the hosts and connects to one of them
@@ -141,9 +155,11 @@ class ConnectionPool(object):
             con = self.get()
             cur = con.cursor()
             cur.execute(query, params)
+            columns = [i[0] for i in cur.description or []]
+            results = [RowResult(r) for r in cur.fetchall()]
             LOG.debug('{} {}'.format(query, repr(params)))
             self.put(con)
-            return cur
+            return QueryResult(columns, results)
         except cql.ProgrammingError as ex:
             raise CQLEngineException(unicode(ex))
         except TTransportException:
@@ -151,12 +167,15 @@ class ConnectionPool(object):
 
         raise CQLEngineException("Could not execute query against the cluster")
 
+
 def execute(query, params={}):
     return connection_pool.execute(query, params)
 
+
 @contextmanager
 def connection_manager():
+    """ :rtype: ConnectionPool """
     global connection_pool
-    tmp = connection_pool.get()
-    yield tmp
-    connection_pool.put(tmp)
+    # tmp = connection_pool.get()
+    yield connection_pool
+    # connection_pool.put(tmp)
