@@ -1,9 +1,12 @@
 import copy
 from datetime import datetime
 from uuid import uuid4
+from hashlib import md5
+from time import time
+from uuid import uuid1
 from cqlengine import BaseContainerColumn, BaseValueManager, Map, columns
 
-from cqlengine.connection import connection_pool, connection_manager, execute
+from cqlengine.connection import connection_manager, execute, RowResult
 
 from cqlengine.exceptions import CQLEngineException
 from cqlengine.functions import QueryValue, Token
@@ -303,12 +306,6 @@ class AbstractQuerySet(object):
         self._execute_query()
         return len(self._result_cache)
 
-    def __del__(self):
-        if self._con:
-            self._con.close()
-            self._con = None
-            self._cur = None
-
     #----query generation / execution----
 
     def _where_clause(self):
@@ -353,11 +350,8 @@ class AbstractQuerySet(object):
         if self._batch:
             raise CQLEngineException("Only inserts, updates, and deletes are available in batch mode")
         if self._result_cache is None:
-            self._cur = execute(self._select_query(), self._where_values())
-            self._result_cache = [None]*self._cur.rowcount
-            if self._cur.description:
-                names = [i[0] for i in self._cur.description]
-                self._construct_result = self._create_result_constructor(names)
+            columns, self._result_cache = execute(self._select_query(), self._where_values())
+            self._construct_result = self._create_result_constructor(columns)
 
     def _fill_result_cache_to_idx(self, idx):
         self._execute_query()
@@ -368,9 +362,9 @@ class AbstractQuerySet(object):
         if qty < 1:
             return
         else:
-            for values in self._cur.fetchmany(qty):
+            for idx in range(qty):
                 self._result_idx += 1
-                self._result_cache[self._result_idx] = self._construct_result(values)
+                self._result_cache[self._result_idx] = self._construct_result(self._result_cache[self._result_idx])
 
             #return the connection to the connection pool if we have all objects
             if self._result_cache and self._result_idx == (len(self._result_cache) - 1):
@@ -382,7 +376,7 @@ class AbstractQuerySet(object):
 
         for idx in range(len(self._result_cache)):
             instance = self._result_cache[idx]
-            if instance is None:
+            if isinstance(instance, RowResult):
                 self._fill_result_cache_to_idx(idx)
             yield self._result_cache[idx]
 
@@ -548,8 +542,8 @@ class AbstractQuerySet(object):
 
             qs = ' '.join(qs)
 
-            cur = execute(qs, self._where_values())
-            return cur.fetchone()[0]
+            _, result = execute(qs, self._where_values())
+            return result[0][0]
         else:
             return len(self._result_cache)
 
@@ -716,7 +710,7 @@ class ModelQuerySet(AbstractQuerySet):
                 return instance
             return _construct_instance
 
-        columns = [model._columns[db_map[name]] for name in names]
+        columns = [model._columns[n] for n in names]
         if self._flat_values_list:
             return (lambda values: columns[0].to_python(values[0]))
         else:
